Crate tauri_plugin_log

Crate tauri_plugin_log 

Logging for Tauri applications.

Cargo features

  • colored: Enables [Builder::with_colors] fern’s colored feature for ANSI-colored outputs.
  • tracing: Emit both log and tracing for the JavaScript log commands.

Re-exports

pub use fern;
pub use log;

Structs

Builder
Target
A log target.

Enums

Error
FileOpenStrategy
LogLevel
An enum representing the available verbosity levels of the logger.
RotationStrategy
TargetKind
An enum representing the available targets of the logger.
TimezoneStrategy

Constants

WEBVIEW_TARGET

Functions

attach_logger
Attaches the given logger